function y = unifhaz(t,A,B)
%UNIFHAZ Uniform hazard rate.
%   Y = UNIFHAZ(t,A,B) returns the hazard function of the Continuous Uniform distribution
%   with parameters A and B evaluated at the values in t. 
%
%   The size of Y is the common size of the input arguments.  A scalar input
%   functions as a constant matrix of the same size as the other inputs.  Each
%   element of Y contains the probability density evaluated at the
%   corresponding elements of the inputs.
%   
%  Reference: Webb, W.M, O'Connor,A.N, Modarres, M, Mosleh, A , Probability Distribution Functions Used In Reliability
%  Engineering, Reliability Information Analysis Center, New York, 2010
%
%   See also UNIFPDF, UNIFCDF, UNIFFIT, UNIFINV, UNIFLIKE, UNIFRND, UNIFSTAT, PDF.
%
%   Author: Andrew O'Connor, occawen(AT)gmail.com

if nargin<1
    error('unifhaz:TooFewInputs','Insufficient number of parameters.');
end
if nargin < 2
    A = 0;
end
if nargin < 3
    B = 1;
end

% Return NaN for out of range parameters.
A(A < 0 | B <= A ) = NaN;
B(A < 0 | B <= A ) = NaN;
y = zeros(size(t));

try
y(t>=A & t<=B) = 1./(B-t(t>=A & t<=B));
    
catch
    error('stats:unifhaz:InputSizeMismatch',...
          'Non-scalar arguments must match in size.');
end
y(t < 0) = 0;
